# eth-abi-tool

Ethereum Contract ABI Utility

![Image](https://img.shields.io/github/license/rstms/eth_abi_tool)

![Image](https://img.shields.io/pypi/v/eth_abi_tool.svg)


![Image](https://circleci.com/gh/rstms/eth_abi_tool/tree/master.svg?style=shield)

![Image](https://readthedocs.org/projects/eth-abi-tool/badge/?version=latest)

![Image](https://pyup.io/repos/github/rstms/eth_abi_tool/shield.svg)


Use blockchain explorer API (currently only etherscan) to query ABI data for a verified contract.

- A CLI interface is provided as well as a python object.
- Includes rate-limiting for use with the various Etherscan account types.


* Free software: MIT license
* Documentation: https://eth-abi-tool.readthedocs.io.


## Credits

This package was created with Cookiecutter and `rstms/cookiecutter-python-cli`, a fork of the `audreyr/cookiecutter-pypackage` project template.

[audreyr/cookiecutter](https://github.com/audreyr/cookiecutter)
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
[rstms/cookiecutter-python-cli](https://github.com/rstms/cookiecutter-python-cli)

## CLI

